=========================
Upgrading from 2.x to 3.x
=========================

From 2.x, some features are removed because splitted other extensions or duplicated behaviors.
If you want to use new version by documentation using 2.x, you should upgrade project files.

Supported dependencies version
==============================

This explicits versions of some dependencies.
If you are using old version libraries,
must update environment. [#]_

+-----------------+--------------+
| Runtime/Library | Requirement  |
+=================+==============+
| Python          | 3.7 or newer |
+-----------------+--------------+
| Sphinx core     | 4.0 or newer |
+-----------------+--------------+

.. [#] This is defined as package metadata on ``pyproject.toml``.
       If your environment does not meet requirements, you cannot install.

Change bundled revealjs path
============================

|THIS| is using Revealjs v5.x(new major version) at version 2.9.0.

If you use path of bundled revealjs directly in other place,
you need to change path.

+---------------+--------------+
| Before        | After        |
+===============+==============+
| ``revealjs4`` | ``revealjs`` |
+---------------+--------------+

You can use :func:`get_revealjs_path <sphinx_revealjs.themes.get_revealjs_path>`.

Change writing structure
========================

.. todo:: Ref to builder document

All slides are "vertical-slides" format
---------------------------------------

Does not generate ``section`` element for level-4 sections
----------------------------------------------------------
